// TriState button implementation
// Copyright (C) 29.08.97 Marco Dettori and Oliver Obst
//
// $Id: tristate.C,v 0.2 1998/03/16 10:56:21 oliver Exp $

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

#include <qpainter.h>
#include <qdrawutl.h>
#include "tristate.h"

// --- public constructor -----------------------------------------------------
// TriState :: TriState
//              constructor with color default

TriState :: TriState(QWidget *parent) : QButton( parent )
{
        state   = EMPTY;
        seen    = FALSE;        

        setColorGroup(blue);
}

        

// --- public constructor -----------------------------------------------------
// TriState :: TriState
//              constructor with color setting

TriState :: TriState(const QColor &color, QWidget *parent) : QButton(parent)
{
        state   = EMPTY;
        seen    = FALSE;

        setColorGroup(color);
}
        

TriState :: ~TriState()
{
}


// TriState public functions

void TriState :: setState(State s)
{
        state   = s;
        paintEvent(0);
}

TriState::State TriState :: getState()
{
        return state;
}


// --- public -----------------------------------------------------------------
// TriState :: setBackgroundColor
//              QColor  & color : set new background color and repaint

void TriState :: setBackgroundColor( const QColor & color )
{
        setColorGroup( color );
        paintEvent( 0 );
}                

// --- public -----------------------------------------------------------------
// TriState:: visit

void TriState :: visit( bool b )
{
        seen = b;
}

// --- public -----------------------------------------------------------------
// TriState:: visited

bool TriState :: visited()
{
        return seen;
}


// redraw button after change has been made
void TriState :: drawButton( QPainter *p )
{
        QRect           r = rect();

        qDrawShadePanel( p, r, colors, isDown(), 1, &fill );
        p->setPen( QPen(white,2) );

        if ( state == CIRCLE )
                p->drawEllipse( r.left() + 4, r.top() + 4,
                                r.width() - 8, r.height() - 8 );
        else
                if ( state == CROSS ) {
                        p->drawLine( r.topLeft() + QPoint(4,4),
                                     r.bottomRight() - QPoint(4,4) );
                        p->drawLine( r.bottomLeft() + QPoint(4,-4),
                                     r.topRight() - QPoint(4,-4) );
                }
}


// --- protected --------------------------------------------------------------
// TriState :: setColorGroup
//
// blue button is default (i.e. if unknown values are given, blue is taken)

void TriState :: setColorGroup( const QColor & color )
{
        if ( color == red ) {
                colors = QColorGroup( white, red, white,
                                      darkRed, red, black, black );
                fill = QBrush( red );
        }
        else if ( color == green ) {
                colors = QColorGroup( white, green, white,
                                      darkGreen, green, black, black );
                fill = QBrush( green );
        }
        else if ( color == cyan ) {
                colors = QColorGroup( white, cyan, white,
                                      darkCyan, cyan, black, black );
                fill = QBrush( cyan );
        }
        else if ( color == yellow ) {
                colors = QColorGroup( white, yellow, white,
                                      darkYellow, yellow, black, black );
                fill = QBrush( yellow );
        }
        else if ( color == magenta ) {
                colors = QColorGroup( white, magenta, white,
                                      darkMagenta, magenta, black, black );
                fill = QBrush( magenta );
        }
        else if ( color == gray ) {
                colors = QColorGroup( white, gray, white,
                                      darkGray, gray, black, black );
                fill = QBrush( gray );
        }
        else if ( color == white ) {
                colors = QColorGroup( white, lightGray, white,
                                      gray, lightGray, black, black );
                fill = QBrush( lightGray );
        }
        else if ( color == black ) {
                colors = QColorGroup( white, darkGray, lightGray,
                                      black, darkGray, black, black );
                fill = QBrush( darkGray );
        } else {
                colors  = QColorGroup( white, blue, white, darkBlue,
                                       blue, black, black );
                fill    = QBrush( blue );
        }
}
